@@ -41,6 +41,7 @@ class Files(BaseModel):
 
 class BaseAlgorithm(ABC):
     __nickname__: str = "not defined"
+    
 
     def __init__(
         self, 
@@ -58,10 +59,15 @@ class BaseAlgorithm(ABC):
         self.persistent_filepaths = persistent_filepaths
         self.result_filepaths = result_filepaths
         self.logger = LoggingLogger(module_name=self.__nickname__)
+        self._variables: dict = {}
 
     def before_load(self):
         pass
 
+    def __add_variable(self, variable_name, value):
+        setattr(self, variable_name, value)
+        self._variables.update({variable_name: value})
+
     def __load_input_file(self) -> None:
         if self.input_filepaths is None:
             return
@@ -71,16 +77,16 @@ class BaseAlgorithm(ABC):
             # 加载 csv 文件
             elif file_type == "csv":
                 for variable_name, filepath in value.items():
-                    setattr(self, variable_name, pd.read_csv(filepath, encoding="GB2312"))
+                    self.__add_variable(variable_name, pd.read_csv(filepath, encoding="GB2312"))
             # 加载 excel 文件
             elif file_type == "excel":
                 for variable_name, filepath in value.items():
-                    setattr(self, variable_name, pd.read_excel(filepath))
+                    self.__add_variable(variable_name, pd.read_excel(filepath))
             # 加载 pickle 文件
             elif file_type == "pickle":
                 for variable_name, filepath in value.items():
                     with open(filepath, "rb") as fr:
-                        setattr(self, variable_name, pickle.load(fr))
+                        self.__add_variable(variable_name, pickle.load(fr))
 
     def __load_persistent_file(self) -> None:
         if self.persistent_filepaths is None:
@@ -91,24 +97,29 @@ class BaseAlgorithm(ABC):
             # 加载 csv 文件
             elif file_type == "csv":
                 for variable_name, filepath in value.items():
-                    setattr(self, variable_name, pd.read_csv(filepath, encoding="GB2312"))
+                    self.__add_variable(variable_name, pd.read_csv(filepath, encoding="GB2312"))
             # 加载 excel 文件
             elif file_type == "excel":
                 for variable_name, filepath in value.items():
-                    setattr(self, variable_name, pd.read_excel(filepath))
+                    self.__add_variable(variable_name, pd.read_excel(filepath))
             # 加载 pickle 文件
             elif file_type == "pickle":
                 for variable_name, filepath in value.items():
                     if not os.path.exists(filepath):
-                        return setattr(self, variable_name, None)
+                        return self.__add_variable(variable_name, None)
                     with open(filepath, "rb") as fr:
-                        setattr(self, variable_name, pickle.load(fr))
+                        self.__add_variable(variable_name, pickle.load(fr))
 
     def load(self) -> None:
         self.__load_input_file()
         self.__load_persistent_file()
         self.logger.info("load finished.")
 
+    def test_load(self) -> None:
+        self.load()
+        self.logger.info("Test Load Result")
+        self.logger.info("Variables followed is created: " + ",".join(self._variables.keys()))
+
     def __output_result_file(self) -> None:
         if self.result_filepaths is None:
             return
@@ -241,6 +252,14 @@ class AlgorithmDevelopmentManager:
                 cls.persistent_filepaths = Filepaths(**persistent_filepaths)
                 break
 
+    @classmethod
+    def test_initialize(cls):
+        cls.initialize()
+        cls.logger.info("Test Filepath Handle Result")
+        cls.logger.info(f"input_filepath: {cls.input_filepaths}")
+        cls.logger.info(f"result_filepath: {cls.result_filepaths}")
+        cls.logger.info(f"persistent_filepath: {cls.persistent_filepaths}")
+
     @classmethod
     def initialize(cls):
         if cls.files != None:
